import { PackageConfig, defaultAuditThresholds } from '@genesislcap/foundation-testing/e2e';
import type { Locator, Page } from '@playwright/test';
import { playAudit } from 'playwright-lighthouse';

export class HeaderPage {
  config: PackageConfig;
  port: number;
  page: Page;
  sideNav: Locator;
  hamburgerMenu: Locator;
  navBarLogo: Locator;
  routeButtons: Locator;
  luminanceToggleButton: Locator;
  miscToggleButton: Locator;
  notificationsButton: Locator;
  connectionIndicator: Locator;
  userButton: Locator;

  constructor(config: PackageConfig, port: number, page: Page) {
    this.config = config;
    this.port = port;
    this.page = page;
    /**
     * Locate fields not guarded by conditionals upfront, and the remaining on-demand
     */
    this.sideNav = this.page.locator('data-test-id=side-nav');
    this.hamburgerMenu = this.page.locator('data-test-id=hamburger-menu');
    this.navBarLogo = this.page.locator('data-test-id=nav-bar-logo');
    this.routeButtons = this.page.locator('data-test-id=route-buttons');
    this.luminanceToggleButton = this.page.locator('data-test-id=luminance-toggle-button');
    this.miscToggleButton = this.page.locator('data-test-id=misc-toggle-button');
    this.notificationsButton = this.page.locator('data-test-id=notifications-button');
    this.connectionIndicator = this.page.locator('data-test-id=connection-indicator');
    this.userButton = this.page.locator('data-test-id=user-button');
  }

  async goto() {
    await this.page.goto('/');
  }

  async audit() {
    await playAudit({
      page: this.page,
      port: this.port,
      thresholds: defaultAuditThresholds, // TODO: this should be coming from foundation-testing/src/playwright/test.ts base config
    });
  }
}
